@@ -1028,9 +1028,10 @@ static int loop(void)
 	for (;;) {
 		rv = poll(pollfd, client_maxi + 1, poll_timeout);
 		if (rv == -1 && errno == EINTR) {
-			if (daemon_quit && list_empty(&lockspaces))
+			if (daemon_quit && list_empty(&lockspaces)) {
 				rv = 0;
 				goto out;
+			}
 			if (daemon_quit) {
 				log_error("shutdown ignored, active lockspaces");
 				daemon_quit = 0;
@@ -1345,6 +1346,11 @@ static void set_opt_defaults(void)
 			1, NULL,
 			"enable/disable startup fencing");
 
+	set_opt_default(repeat_failed_fencing_ind,
+			"repeat_failed_fencing", '\0', req_arg_bool,
+			1, NULL,
+			"enable/disable retrying after fencing fails");
+
 	set_opt_default(enable_quorum_fencing_ind,
 			"enable_quorum_fencing", 'q', req_arg_bool,
 			1, NULL,
